# taomn <a href="https://gitter.im/taoblockchain/taomn"><img align="right" src="https://badges.gitter.im/gitterHQ/gitter.png"></a>

| Branch  | Status | Coverage |
| --- | --- | --- |
| Master | [![Build Status](https://travis-ci.org/taoblockchain/taomn.svg?branch=master)](https://travis-ci.org/taoblockchain/taomn) | [![Coverage Status](https://coveralls.io/repos/github/taoblockchain/taomn/badge.svg?branch=master)](https://coveralls.io/github/taoblockchain/taomn?branch=master) |
| Develop | [![Build Status](https://travis-ci.org/taoblockchain/taomn.svg?branch=develop)](https://travis-ci.org/taoblockchain/taomn) | [![Coverage Status](https://coveralls.io/repos/github/taoblockchain/taomn/badge.svg?branch=develop)](https://coveralls.io/github/taoblockchain/taomn?branch=develop) |

Tao MasterNode (taomn) is a cli tool to help you run a Tao masternode

## Running and applying a masternode

If you are consulting this repo, it's probably because you want to run a masternode.
For complete guidelines on running a masternode candidate, please refer to the [documentation](https://docs.tao.network/masternode/requirements/).
